// 																														JWAC Forecasting Project
// 																															(Central Asia models)
//____________________________________________________________________________________
// 																		  												CASIASQ/WEISSQ Filter
//
//	Programmer: Philip A. Schrodt
//	Compiler:		Metrowerks C
//	Language:		ANSI C
//
//
//__________________________________________________________________________________
//                                       													 #define constants
#define FALSE  					 0
#define TRUE  					 1

#define LINELENGTH  	 100
#define	CODE_LENGTH			 7		// maximum length of actor code string, plus 1
#define	DATE_LENGTH			 7		// length of date string, plus 1
#define	MAX_DYADS			 	16		// maximum dyads
#define N_EVT_CODES			22		// number of non-zero event categories
#define N_XFORM_CODES		 4		// number of transformed event categories 

#define	WILD_CARD_CODE	"***"	// wild card actor code
#define	DYAD_END_STRG		"==="	// string signaling end of dyad file

#define DATA_FILE 	"LBR.events"	// name of event data input file
#define DYAD_FILE 	"LBR.DYADS"			// name of file of dyads to be compiled
//#define DATA_FILE 	"AFG.ALL.EVT"	// name of event data input file
//#define DYAD_FILE 	"AFG.DYADS"			// name of file of dyads to be compiled
//#define DATA_FILE 	"CASIA.ALL.EVT.3CODE"	// name of event data input file
//#define DYAD_FILE 	"ARMAZR.DYADS"			// name of file of dyads to be compiled
//#define DYAD_FILE 	"RUSTAJ.DYADS"			// name of file of dyads to be compiled
#define OUT_PREFIX 	"XFRMSQ."							// prefix for transformed sequence output file name
#define DIST_PREFIX "DIST."								// prefix for distribution output file name

#define DO_RANDOM			FALSE		// generate random sequences?
#define DO_XFORM			TRUE		// transform the codes?

//__________________________________________________________________________________
// 																																				Prototypes

void Initialize( void );				// Open assorted files
void Make_Sequence(void);				// generate a sequence of given actor and target
void Write_Dist(void);					// write the event distribution
long Julian (char *s);												// returns a Julian (sequential) date based on the YYMMDD date string

#if DO_RANDOM
double UnifRnd( void );								// functions for generating a random sequence
int Get_Random_Event ( void );
void Make_Random( void );
#endif

//__________________________________________________________________________________________
// 																																								Globals

FILE		*fin, *fout, *fconv;									// input and output files
int			Month[] = {0,0,31,59,90,120,151,181,212,243,273,304,334};		// used for Julian computation: # days prior to Month[n] JAN=1
char		Src_Code[MAX_DYADS][CODE_LENGTH];			// dyad source codes
char		Tar_Code[MAX_DYADS][CODE_LENGTH];			// dyad target codes	
int			N_Dyads;															// number of dyads
int			Evt_Dist[MAX_DYADS][N_EVT_CODES];			// distribution of events
int			Zero_Dist;
char    Suffix[33];														// file suffix read from DYAD_FILE; note that 33 is actually too long for a suffix
int			Xform_Codes[N_EVT_CODES+1];							// transformation map for reduced codes
#if DO_RANDOM
	
float   evtprob[]={0.36,0.005,0.05,0.10,0.01,0.005,0.02,0.01,0.04,0.02,0.01,0.03,0.02,
									 0.01,0.005,0.01,0.005,0.01,0.01,0.03,0.01,0.04,0.19};		// WEIS marginal probabilities
									 
#endif